@@ -13,7 +13,7 @@ function prepare_images {
     fi
 
     if [[ $SCENARIO != "bifrost" ]]; then
-        GATE_IMAGES="^cron,^fluentd,^glance,^haproxy,^keepalived,^keystone,^kolla-toolbox,^mariadb,^memcached,^neutron,^nova-,^openvswitch,^rabbitmq,^horizon,^heat,^placement"
+        GATE_IMAGES="^cron,^fluentd,^glance,^haproxy,^proxysql,^keepalived,^keystone,^kolla-toolbox,^mariadb,^memcached,^neutron,^nova-,^openvswitch,^rabbitmq,^horizon,^heat,^placement"
     else
         GATE_IMAGES="bifrost"
     fi
@@ -37,7 +37,7 @@ function prepare_images {
         GATE_IMAGES+=",^aodh,^tacker,^mistral,^redis,^barbican"
     fi
     if [[ $SCENARIO == "ironic" ]]; then
-        GATE_IMAGES+=",^dnsmasq,^ironic,^iscsid,^prometheus"
+        GATE_IMAGES+=",^dnsmasq,^ironic,^iscsid"
     fi
     if [[ $SCENARIO == "magnum" ]]; then
         GATE_IMAGES+=",^designate,^magnum,^trove"
@@ -58,7 +58,7 @@ function prepare_images {
     fi
 
     if [[ $SCENARIO == "mariadb" ]]; then
-        GATE_IMAGES="^cron,^fluentd,^haproxy,^keepalived,^kolla-toolbox,^mariadb"
+        GATE_IMAGES="^cron,^fluentd,^haproxy,^proxysql,^keepalived,^kolla-toolbox,^mariadb"
     fi
 
     if [[ $SCENARIO == "lets-encrypt" ]]; then
@@ -66,14 +66,14 @@ function prepare_images {
     fi
 
     if [[ $SCENARIO == "prometheus-opensearch" ]]; then
-        GATE_IMAGES="^cron,^fluentd,^grafana,^haproxy,^keepalived,^kolla-toolbox,^mariadb,^memcached,^opensearch,^prometheus,^rabbitmq"
+        GATE_IMAGES="^cron,^fluentd,^grafana,^haproxy,^proxysql,^keepalived,^kolla-toolbox,^mariadb,^memcached,^opensearch,^prometheus,^rabbitmq"
     fi
 
     if [[ $SCENARIO == "venus" ]]; then
-        GATE_IMAGES="^cron,^opensearch,^fluentd,^haproxy,^keepalived,^keystone,^kolla-toolbox,^mariadb,^memcached,^rabbitmq,^venus"
+        GATE_IMAGES="^cron,^opensearch,^fluentd,^haproxy,^proxysql,^keepalived,^keystone,^kolla-toolbox,^mariadb,^memcached,^rabbitmq,^venus"
     fi
 
-    if [[ $SCENARIO == "skyline" ]]; then
+    if [[ $SCENARIO == "skyline" || $SCENARIO == "skyline-sso" ]]; then
         GATE_IMAGES+=",^skyline"
     fi
 
@@ -88,12 +88,6 @@ base_image = quay.io/openstack.kolla/${BASE_DISTRO}
 EOF
     fi
 
-    if [[ $BASE_DISTRO_TAG != "" ]]; then
-        sudo tee -a /etc/kolla/kolla-build.conf <<EOF
-base_tag = ${BASE_DISTRO_TAG}
-EOF
-    fi
-
     sudo tee -a /etc/kolla/kolla-build.conf <<EOF
 [profiles]
 gate = ${GATE_IMAGES}
@@ -108,7 +102,7 @@ EOF
     python3 -m venv ~/kolla-venv
     source ~/kolla-venv/bin/activate
     if [[ "$CONTAINER_ENGINE" == "docker" ]]; then
-        pip install "${KOLLA_SRC_DIR}" "docker<7" "requests<2.32"
+        pip install "${KOLLA_SRC_DIR}" "docker"
     else
         pip install "${KOLLA_SRC_DIR}" "podman"
     fi
@@ -130,7 +124,7 @@ EOF
 RAW_INVENTORY=/etc/kolla/inventory
 
 source $KOLLA_ANSIBLE_VENV_PATH/bin/activate
-kolla-ansible -i ${RAW_INVENTORY} -vvv bootstrap-servers &> /tmp/logs/ansible/bootstrap-servers
+kolla-ansible bootstrap-servers -i ${RAW_INVENTORY} -vvv  &> /tmp/logs/ansible/bootstrap-servers
 deactivate
 
 prepare_images
